summaryrefslogtreecommitdiffstats
path: root/devel/phpsh/files/patch-src_phpsh.php
blob: 0238999575b0b9410a72833d61012246e62bfec5 (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
--- src/phpsh.php.orig
+++ src/phpsh.php
@@ -10,7 +10,7 @@
 // usage: this is only called from phpsh (the python end), as:
 // phpsh.php <comm-file> <codebase-mode> [-c]
 //
 // use '' for default codebase-mode, define others in /etc/phpsh/rc.php
 // -c turns off color
 
 // set the TFBENV to script
@@ -46,7 +46,7 @@
 if (file_exists($___phpsh___homerc)) {
   require_once $___phpsh___homerc;
 } else {
-  require_once '/etc/phpsh/rc.php';
+  require_once '%%ETCDIR%%/rc.php';
 }
 
 $___phpsh___do_color = true;
@@ -547,7 +547,7 @@
           $err_msg =
             'Not executing input: Possible call to undefined function '.
             $undefd_func."()\n".
-            'See /etc/phpsh/config.sample to disable UndefinedFunctionCheck.';
+            'See %%ETCDIR%%/config.sample to disable UndefinedFunctionCheck.';
         }
       }
       if ($err_msg) {
@@ -10,7 +10,7 @@
 // phpsh.php <comm-file> <codebase-mode> [-c]
 //
-// use '' for default codebase-mode, define others in /etc/phpsh/rc.php
+// use '' for default codebase-mode, define others in %%ETCDIR%%/rc.php
 // -c turns off color
 
OpenPOWER on IntegriCloud